<?php

namespace App\Http\Controllers;
use App\Models\Contact;
use App\Models\Contacttype;
use App\Models\Stocktransaction;

use Illuminate\Http\Request;

class ContactController extends Controller
{
    public function getContact(){
        $data = Contact::with('type')->orderBy('id', 'desc')->get();
        
        $response = [
            'success'=>true,
            'contact'=>$data,
        ];
        
        return response($response,200);
    }

    public function getContactCustomer(){
        $data = Contact::whereHas('type', function($type){
            $type->where('category','=','customer');
        })->get();   

        $response = [
            'success'=>true,
            'contact'=>$data,
        ];
        
        return response($response,200);
    }

    public function getContactSupplier(){
        $data = Contact::whereHas('type', function($type){
                    $type->where('category','=','supplier');
                })->get();   

        $response = [
            'success'=>true,
            'contact'=>$data,
        ];
        
        return response($response,200);
    }
    
    public function getContactVendor(){
        $data = Contact::whereHas('type', function($type){
                    $type->where('category','=','vendor');
                })->get();   

        $response = [
            'success'=>true,
            'contact'=>$data,
        ];
        
        return response($response,200);
    }

    public function getContactKaryawan(){
        $data = Contact::whereHas('type', function($type){
                    $type->where('category','=','karyawan');
                })->get();   

        $response = [
            'success'=>true,
            'contact'=>$data,
        ];
        
        return response($response,200);
    }

    public function getContactVendorandKaryawan(){
        $data = Contact::with('type')
            ->whereHas('type', function($type) {
                $type->whereIn('category', ['vendor', 'karyawan']);
            })
            ->orderBy('id', 'desc')
            ->get();

        $response = [
            'success'=>true,
            'contact'=>$data,
        ];
        
        return response($response,200);
    }
    public function getContactDetail(Request $request){
        $data = Contact::find($request->id);
        
        $response = [
            'success'=>true,
            'contact'=>$data,
        ];
        
        return response($response,200);
    }

    public function createContact(Request $request){
        $request->validate([
            'name' =>'required',
            'desc' =>'nullable',
            'address'  =>'nullable',
            'contact'  =>'nullable',
            'npwp'  =>'nullable',
            'bank_account_name'  =>'nullable',
            'bank_account_number'  =>'nullable',
            'type'  =>'required',
        ]);

        $data = new Contact;
        $data->name = $request->name;
        $data->desc = $request->desc;
        $data->address = $request->address;
        $data->contact = $request->contact;
        $data->contact_title = $request->contact_title;
        $data->contact_email = $request->contact_email;
        $data->type = $request->type;
        $data->npwp = $request->npwp;
        $data->bank_account_name = $request->bank_account_name;
        $data->bank_account_number = $request->bank_account_number;
        $data->save();
        
        $response = [
            'success'=>true,
            'contact'=>$data,
        ];
        
        return response($response,200);
    }

    public function editContact(Request $request){
        $request->validate([
            'name' =>'required',
            'desc' =>'nullable',
            'address'  =>'nullable',
            'contact'  =>'nullable',
            'npwp'  =>'nullable',
            'bank_account_name'  =>'nullable',
            'bank_account_number'  =>'nullable',
            'type'  =>'required',
        ]);

        $data = Contact::find($request->id);
        $data->name = $request->name;
        $data->desc = $request->desc;
        $data->address = $request->address;
        $data->contact = $request->contact;
        $data->contact_title = $request->contact_title;
        $data->contact_email = $request->contact_email;
        $data->type = $request->type;
        $data->npwp = $request->npwp;
        $data->bank_account_name = $request->bank_account_name;
        $data->bank_account_number = $request->bank_account_number;
        $data->save();
        
        $response = [
            'success'=>true,
            'contact'=>$data,
        ];
        
        return response($response,200);
    }

    public function deleteContact(Request $request){

        $transaction = Stocktransaction::where('contact_id',$request->id)->get();
        if (!$transaction->isEmpty()) {
            return response(['message' => 'Contact sudah pernah digunakan untuk transaksi'], 400);
        }

        $data = Contact::find($request->id);
        $data->delete();
        
        $response = [
            'success'=>true,
            'contact'=>$data,
            'transaction'=>$transaction,
        ];
        
        return response($response,200);
    }   
}
